==> musashi-core-1.0.3.tar.gz: musashi-core-1.0.3/help/ja-sjis/xtclassifyHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT ""

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-p*/
#define PATT "p^[ږXg"
#define PATC "p^["
#define PATF "l"

/*-n*/
#define NUMT "lږXg"
#define NUMC "l"
#define NUMF NULL

/*-d*/
#define CATT "JeSږXg"
#define CATC "JeS"
#define CATF NULL

/*-c*/
#define CLST "NXږ"
#define CLSC "NX"
#define CLSF NULL

/*-i*/
#define TRNT "g[jOf[^t@C"
#define TRNC "g[jOf[^"

/*-I*/
#define TSTT "eXgf[^t@C"
#define TSTC "w肪΃g[jOf[^݂̂ŕފ𐶐"

/*-o*/
#define OTFT "eLXgɂ錋ʏo̓t@C"
#define OTFC "w肪ΕWo͂ɏo"

/*-P*/
#define PMLT "PMMLɂ錋ʏo̓t@C"
#define PMLC "PMMLɂ錋ʏo̓t@C"

/*-D*/
#define DLMT "f~^"
#define DLMC "p^[ڂ̗vfԂ̋؂蕶"

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-C*/
#define CSTT "RXgt@C"
#define CSTC "w肪΁ASẴRXgPƂČvZ"

/*-m*/
#define MDLT "f̎"
#define MDLC "f"
#define MDLF ",[Zbg,̈惋["

/*-Q*/
#define SEQT "TuV[PX"
#define SEQC "ȗƃTuXgO"

/*-E*/
#define ENDT "I[nv"
#define ENDC "I[nv𐳋Kp^[ɉ"

/*-B*/
#define BGNT "擪nv"
#define BGNC "擪nv𐳋Kp^[ɉ"

/*-s*/
#define SIZT "CfbNX̃TCY"
#define SIZC "IWĩAt@xbgO[v邽߂̃CfbNX̃TCYw肷(ȗ͂Q)"

/*-S*/
#define SEDT "̎"
#define SEDC "[JT[`ŗp闐̎w肷"

/*-L*/
#define CANT "Kp^[␔"
#define CANC "Kp^[̌␔̏w肷"

/*-l*/
#define TRYT "[JT[`"
#define TRYC "[JT[`"

/*-g*/
#define SPLT "splitting rule"
#define SPLC "fsplitting rule"
#define SPLF "Gini,Entropy,GeoMean"

/*-b*/
#define PRBT "m̌vZ@"
#define PRBC "f̊eNXom̌vZ@"
#define PRBF "VFA,VFA+RXg,LaplaceEstimate,LaplaceEstimate+RXg"

/*-r*/
#define PMDT "}̕@"
#define PMDC "}̕@"
#define PMDF "}Ȃ,Error-Based Pruning,Reduced Error Pruning"

/*-R*/
#define PRNT "}pf[^t@C"
#define PRNC "Reduced Error Pruningɂ}pf[^t@C"

/*-F*/
#define CNFT "}x"
#define CNFC "0-100̒lBl}BftHg25B"

/*-M*/
#define MINT "m[hŏP[X"
#define MINC "em[hɊ܂܂ŏP[X"

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "p^[,l,JeSƂĎf[^Ɋւ镪ރf𐶐B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtclassify -p pattern -c Class -idat.trn -Idat.tst\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\\B                  */
/* o^Ȃ(#define HELPB "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\\B                 */
/* o^Ȃ(#define HELPH "")\\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH

==> musashi-core-1.0.4-pre6.tar.gz: musashi-core-1.0.4-pre6/help/ja-sjis/xtclassifyHelp.h <==

#include "commonHelp.h"
/*============================================================================*/
/* R}hwv,man,musahi GUI ʃbZ[WǗ                           */
/*============================================================================*/
/*----------------------------------------------------------------------------*/
/* R}h̃^Cg                                                         */
/* R}hwv̍ŏ̍sɕ\                                             */
/*----------------------------------------------------------------------------*/
#define HELPT "ރf̐"

/*----------------------------------------------------------------------------*/
/* p[^                                                                 */
/* R}hwv USAGE:Ƃ"L[[h XXXT"\ ex)-k L[ږXg*/
/* flag̃IvV̓R}hwvOPTIONS)Ƃĕ\ ex)-z : Wo͂̈k*/
/*----------------------------------------------------------------------------*/
/*-p*/
#define PATT "p^[ږXg"
#define PATC "p^["
#define PATF "l"

/*-n*/
#define NUMT "lږXg"
#define NUMC "l"
#define NUMF NULL

/*-d*/
#define CATT "JeSږXg"
#define CATC "JeS"
#define CATF NULL

/*-c*/
#define CLST "NXږ"
#define CLSC "NX"
#define CLSF NULL

/*-i*/
#define TRNT "g[jOf[^t@C"
#define TRNC "g[jOf[^"

/*-I*/
#define TSTT "eXgf[^t@C"
#define TSTC "w肪΃g[jOf[^݂̂ŕފ𐶐"

/*-o*/
#define OTFT "eLXgɂ錋ʏo̓t@C"
#define OTFC "w肪ΕWo͂ɏo"

/*-P*/
#define PMLT "PMMLɂ錋ʏo̓t@C"
#define PMLC "PMMLɂ錋ʏo̓t@C"

/*-D*/
#define DLMT "f~^"
#define DLMC "p^[ڂ̗vfԂ̋؂蕶"

/*-t*/
#define TXTT C_TXTT
#define TXTC C_TXTC

/*-C*/
#define CSTT "RXgt@C"
#define CSTC "w肪΁ASẴRXgPƂČvZ"

/*-m*/
#define MDLT "f̎"
#define MDLC "f"
#define MDLF ",[Zbg,̈惋["

/*-Q*/
#define SEQT "TuV[PX"
#define SEQC "ȗƃTuXgO"

/*-E*/
#define ENDT "I[nv"
#define ENDC "I[nv𐳋Kp^[ɉ"

/*-B*/
#define BGNT "擪nv"
#define BGNC "擪nv𐳋Kp^[ɉ"

/*-s*/
#define SIZT "CfbNX̃TCY"
#define SIZC "IWĩAt@xbgO[v邽߂̃CfbNX̃TCYw肷(ȗ͂Q)"

/*-S*/
#define SEDT "̎"
#define SEDC "[JT[`ŗp闐̎w肷"

/*-L*/
#define CANT "Kp^[␔"
#define CANC "Kp^[̌␔̏w肷"

/*-l*/
#define TRYT "[JT[`"
#define TRYC "[JT[`"

/*-g*/
#define SPLT "splitting rule"
#define SPLC "fsplitting rule"
#define SPLF "Gini,Entropy,GeoMean"

/*-b*/
#define PRBT "m̌vZ@"
#define PRBC "f̊eNXom̌vZ@"
#define PRBF "VFA,VFA+RXg,LaplaceEstimate,LaplaceEstimate+RXg"

/*-r*/
#define PMDT "}̕@"
#define PMDC "}̕@"
#define PMDF "}Ȃ,Error-Based Pruning,Reduced Error Pruning"

/*-R*/
#define PRNT "}pf[^t@C"
#define PRNC "Reduced Error Pruningɂ}pf[^t@C"

/*-F*/
#define CNFT "}x"
#define CNFC "0-100̒lBl}BftHg25B"

/*-M*/
#define MINT "m[hŏP[X"
#define MINC "em[hɊ܂܂ŏP[X"

/*----------------------------------------------------------------------------*/
/* v                                                                       */
/* R}hwvSUMMARY:Ƃĕ\                                     */
/* HTMLwvmanɂ́AHELPD̏Ɍ`ŕ\                   */
/*----------------------------------------------------------------------------*/
#define HELPS "p^[,l,JeSƂĎf[^Ɋւ镪ރf𐶐B"

/*----------------------------------------------------------------------------*/
/*                                                                          */
/*----------------------------------------------------------------------------*/
#define HELPE "\
xtclassify -p pattern -c Class -idat.trn -Idat.tst\n\
"

/*----------------------------------------------------------------------------*/
/* QƃR}h(KJ}ŋ؂A󔒂͗pȂ)                           */
/*----------------------------------------------------------------------------*/
#define HELPR ""

/*----------------------------------------------------------------------------*/
/* ҂ɂ                                                               */
/* R}hwvɂ͕\Ȃ                                             */
/*----------------------------------------------------------------------------*/
#define HELPA C_HELPA

/*----------------------------------------------------------------------------*/
/* oO|[g                                                               */
/* o^΃R}hwvBUG REPORT:ɕ\B                  */
/* o^Ȃ(#define HELPB "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPB C_HELPB

/*----------------------------------------------------------------------------*/
/* z[y[W                                                               */
/* o^΃R}hwvINFORMATION:ɕ\B                 */
/* o^Ȃ(#define HELPH "")\ȂB                           */
/*----------------------------------------------------------------------------*/
#define HELPH C_HELPH
